safesql

package
v0.30.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 31, 2026 License: Apache-2.0 Imports: 1 Imported by: 0

Documentation

Overview

Package safesql implements an SQL type that can be used to mark SQL strings.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type SQL

type SQL struct {
	// contains filtered or unexported fields
}

SQL holds an SQL string

func Concat

func Concat(ss ...SQL) SQL

Concat SQL parts together.

func Make

func Make(s stringConstant) SQL

Make creates an SQL value from an untyped string constant.

func (SQL) String

func (s SQL) String() string

type SQLer

type SQLer interface{ SQL() string }

SQL holds an SQL string

Directories

Path Synopsis
cmd
safesql command
typeindex
Package typeindex defines an analyzer that provides a golang.org/x/tools/internal/typesinternal/typeindex.Index.
Package typeindex defines an analyzer that provides a golang.org/x/tools/internal/typesinternal/typeindex.Index.

Jump to