package
Version:
v0.30.0
Opens a new window with list of versions in this module.
Published: Jul 31, 2026
License: Apache-2.0
Opens a new window with license information.
Imports: 1
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
Package safesql implements an SQL type that can be used to
mark SQL strings.
SQL holds an SQL string
Concat SQL parts together.
func Make(s stringConstant) SQL
Make creates an SQL value from an untyped string constant.
type SQLer interface{ SQL() string }
SQL holds an SQL string
Source Files
¶
Directories
¶
cmd
|
|
|
|
|
|
|
|
typeindex
Package typeindex defines an analyzer that provides a golang.org/x/tools/internal/typesinternal/typeindex.Index.
|
Package typeindex defines an analyzer that provides a golang.org/x/tools/internal/typesinternal/typeindex.Index. |
Click to show internal directories.
Click to hide internal directories.